/**
 * Sample JavaScript for IIR API Demonstration
 */
var bearerToken = 'YOUR_BEARER_TOKEN';

var offlineEventsURL =
    'https://api.industrialinfo.com/idb/v1.1/offlineevents/summary?eventKind=S&eventStatusDesc=Ongoing&unitTypeId=00203&industryCode=04';
    
var  plantDetailsURL = 'https://api.industrialinfo.com/idb/v1.1/plants/detail?';

// UI variables
var map = new google.maps.Map(document.getElementById('demo-map'), {
    center: { lat: 26.422, lng: -14.921 },
    zoom: 1,
    zoomControl: true,
    mapTypeControl: false,
    scaleControl: false,
    streetViewControl: false,
    rotateControl: false,
    fullscreenControl: false,
  });  
var table = document.getElementById('demo-table');

function processOfflineEventData()    
{    
  fetch(offlineEventsURL, {
    method: 'POST',
    headers: {
      Authorization: 'Bearer ' + bearerToken,
    },
    'Content-Type': 'application/json',
  })
  .then((response) => {
      return response.json()
  })
  .then((json) => {
      displayTableData(json.offlineEvents)
      processPlantData(extractPlantIDs(json.offlineEvents))
   })
}

function displayTableData (data) {
  // update table head
  table.tHead.innerHTML = `
  <tr>
    <th>Unit Name</th>
    <th>Unit ID</th>
    <th>Offline Capacity</th>
    <th>Event Type</th>
  </tr>`

  // update table body
  table.tBodies[0].innerHTML = ''
  data.forEach((event) => {
    table.tBodies[0].innerHTML += `
      <tr>
        <td>${event.unitName}</td>
        <td>${event.unitId}</td>
        <td>${event.offlineCapacity.capacityOffline} ${event.offlineCapacity.uom}</td>
        <td>${event.eventType}</td>
      </tr>`
  })
}

function extractPlantIDs(data)    
{    
  return [
    ...new Set(
      data.map((result) => {
        return result.plantId
      })
    ),
  ]
}

function processPlantData (data)
{
  var plantIdQueryString = 'plantId=' + data.join('&plantId=');
    
  fetch(plantDetailsURL + plantIdQueryString, {
    method: 'POST',
    headers: {
      Authorization: 'Bearer ' + bearerToken,
    },
    'Content-Type': 'application/json',
  })
    .then((response) => {
      return response.json()
    })
    .then((json) => {
      displayMapData(json.plants)
    })
}

function displayMapData(data) 
{
    data.forEach((plant) => {
        var marker = new google.maps.Marker({
          position: { lat: plant.latitude, lng: plant.longitude },
          map: map,
          title: plant.plantName,
    });
    var infowindow = new google.maps.InfoWindow({
        content: plant.plantName,
    });
    
    marker.addListener('click', () => {
      infowindow.open(map, marker)
    })
  })
}

processOfflineEventData();
