/**
 * Sample JavaScript for IIR API Demonstration
 */
const bearerToken =
    'eyJhbGciOiJIUzI1NiJ9.eyJqdGkiOiI3NzIxNzQiLCJzdWIiOiJndHNhaSIsImF1ZCI6IklJUl9BUEkiLCJpc3MiOiJJbmR1c3JpYWwgSW5mbyBSZXNvdXJjZXMiLCJpYXQiOjE1ODUxNTU5NTYsImV4cCI6MTU4Nzc0Nzk1Nn0.CYJ_gVsSfjMzWLwfi32anHxiHY2Mejadd56-MuC02Cc',
  offlineEventsURL =
    'https://api.industrialinfo.com/idb/v1.1/offlineevents/summary?eventKind=S&eventStatusDesc=Ongoing&unitTypeId=00203&industryCode=04',
  plantDetailsURL = 'https://api.industrialinfo.com/idb/v1.1/plants/detail?'

// UI variables
let map,
  table = document.getElementById('demo-table')

const initMap = () => {
  map = new google.maps.Map(document.getElementById('demo-map'), {
    center: { lat: 26.422, lng: -14.921 },
    zoom: 1,
    zoomControl: true,
    mapTypeControl: false,
    scaleControl: false,
    streetViewControl: false,
    rotateControl: false,
    fullscreenControl: false,
  })

  getInitialData()
}

const getInitialData = () => {
  fetch(offlineEventsURL, {
    method: 'POST',
    headers: {
      Authorization: 'Bearer ' + bearerToken,
    },
    'Content-Type': 'application/json',
  })
    .then((response) => {
      return response.json()
    })
    .then((json) => {
      displayTableData(json.offlineEvents)
      getPlantData(extractPlantIDs(json.offlineEvents))
    })
}

const displayTableData = (data) => {
  // update table head
  table.tHead.innerHTML = `
  <tr>
    <th>Unit Name</th>
    <th>Unit ID</th>
    <th>Offline Capacity</th>
    <th>Event Type</th>
  </tr>`

  // update table body
  table.tBodies[0].innerHTML = ''
  data.forEach((event) => {
    table.tBodies[0].innerHTML += `
      <tr>
        <td>${event.unitName}</td>
        <td>${event.unitId}</td>
        <td>${event.offlineCapacity.capacityOffline} ${event.offlineCapacity.uom}</td>
        <td>${event.eventType}</td>
      </tr>`
  })
}

const extractPlantIDs = (data) => {
  return [
    ...new Set(
      data.map((result) => {
        return result.plantId
      })
    ),
  ]
}

const getPlantData = (data) => {
  const plantIdQueryString = 'plantId=' + data.join('&plantId=')

  fetch(plantDetailsURL + plantIdQueryString, {
    method: 'POST',
    headers: {
      Authorization: 'Bearer ' + bearerToken,
    },
    'Content-Type': 'application/json',
  })
    .then((response) => {
      return response.json()
    })
    .then((json) => {
      displayPlantData(json.plants)
    })
}

const displayPlantData = (data) => {
  data.forEach((plant) => {
    const marker = new google.maps.Marker({
      position: { lat: plant.latitude, lng: plant.longitude },
      map: map,
      title: plant.plantName,
    })
    const infowindow = new google.maps.InfoWindow({
      content: plant.plantName,
    })
    marker.addListener('click', () => {
      infowindow.open(map, marker)
    })
  })
}

initMap()
